@@ -51,11 +51,11 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of the invoice item (minor units). Example: 1000 = 10.00 (B<required>) 
+Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] (B<required>) 
 
 =item currency
 
-Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. (B<required>) (B<default:USD>)
+Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] (B<required>) 
 
 =item description
 
@@ -102,20 +102,17 @@ Filters to apply to the list.
 
 
 
-
 =item C<max>
 
-Allows up to a max of 50 list items to return.
+Allows up to a max of 50 list items to return. [max value: 50, default: 20]
 
 
-(B<default: 20>)
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page.
+Used in paging of the list.  This is the start offset of the page. [default: 0]
 
 
-(B<default: 0>)
 
 =item C<sorting>
 
@@ -138,7 +135,6 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 
 
-
 =back
 
 =back
@@ -175,15 +171,15 @@ The properties that can be updated are:
 
 =item C<amount>
 
-
+Amount of the invoice item (minor units). Example: 1000 = 10.00 [min value: 1, max value: 99999999] 
 
 =item C<currency>
 
-
+Currency code (ISO-4217) for the invoice item. Must match the currency associated with your account. [default: USD] 
 
 =item C<description>
 
-
+Individual items of an invoice 
 
 
 Authentication is done using the same credentials used when the AccessToken was created.
@@ -204,11 +200,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.4
+1.0.5
 
 =head1 LICENSE
 
-Copyright (c) 2013, MasterCard International Incorporated
+Copyright (c) 2013, 2014 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
