@@ -42,33 +42,33 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of the payment (minor units). Example: 1000 = 10.00 (B<required>) 
+Amount of the payment (minor units). Example: 1000 = 10.00 [min value: 50, max value: 99999999] (B<required>) 
 
 
 
 =item card.addressCity
 
-City of the cardholder. 
+City of the cardholder. [max length: 50, min length: 2] 
 
 =item card.addressCountry
 
-Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. 
+Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] 
 
 =item card.addressLine1
 
-Address of the cardholder. 
+Address of the cardholder. [max length: 255] 
 
 =item card.addressLine2
 
-Address of the cardholder if needed. 
+Address of the cardholder if needed. [max length: 255] 
 
 =item card.addressState
 
-State code (USPS code) of residence of the cardholder. 
+State code (USPS code) of residence of the cardholder. [max length: 2, min length: 2] 
 
 =item card.addressZip
 
-Postal code of the cardholder. 
+Postal code of the cardholder. The postal code size is between 5 and 9 in length and only contain numbers. [max length: 9, min length: 3] 
 
 =item card.cvc
 
@@ -76,23 +76,23 @@ CVC security code of the card. This is the code on the back of the card. Example
 
 =item card.expMonth
 
-Expiration month of the card. Format is MM. Example: January = 01 (B<required>) 
+Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] (B<required>) 
 
 =item card.expYear
 
-Expiration year of the card. Format is YY. Example: 2013 = 13 (B<required>) 
+Expiration year of the card. Format is YY. Example: 2013 = 13 [max value: 99] (B<required>) 
 
 =item card.name
 
-Name as it appears on the card. 
+Name as it appears on the card. [max length: 50, min length: 2] 
 
 =item card.number
 
-Card number as it appears on the card. (B<required>) 
+Card number as it appears on the card. [max length: 19, min length: 13] (B<required>) 
 
 =item currency
 
-Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. (B<required>) (B<default:USD>)
+Currency code (ISO-4217) for the transaction. Must match the currency associated with your account. [default: USD] (B<required>) 
 
 =item customer
 
@@ -108,7 +108,7 @@ Custom reference field to be used with outside systems.
 
 =item token
 
-If specified, card associated with card token will be used. 
+If specified, card associated with card token will be used. [max length: 255] 
 
 
 =back
@@ -141,20 +141,17 @@ Filters to apply to the list.
 
 
 
-
 =item C<max>
 
-Allows up to a max of 50 list items to return.
+Allows up to a max of 50 list items to return. [max value: 50, default: 20]
 
 
-(B<default: 20>)
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page.
+Used in paging of the list.  This is the start offset of the page. [default: 0]
 
 
-(B<default: 0>)
 
 =item C<sorting>
 
@@ -179,7 +176,6 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 
 
-
 =back
 
 =back
@@ -218,11 +214,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.4
+1.0.5
 
 =head1 LICENSE
 
-Copyright (c) 2013, MasterCard International Incorporated
+Copyright (c) 2013, 2014 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
