@@ -51,11 +51,11 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of payment for the plan in minor units. Example: 1000 = 10.00 (B<required>) 
+Amount of payment for the plan in minor units. Example: 1000 = 10.00 [min value: 50, max value: 99999999] (B<required>) 
 
 =item currency
 
-Currency code (ISO-4217) for the plan. Must match the currency associated with your account. (B<required>) (B<default:USD>)
+Currency code (ISO-4217) for the plan. Must match the currency associated with your account. [default: USD] (B<required>) 
 
 =item frequency
 
@@ -63,7 +63,7 @@ Frequency of payment for the plan. Example: Monthly (B<required>)
 
 =item name
 
-Name of the plan (B<required>) 
+Name of the plan [max length: 50, min length: 2] (B<required>) 
 
 
 =back
@@ -102,20 +102,17 @@ Filters to apply to the list.
 
 
 
-
 =item C<max>
 
-Allows up to a max of 50 list items to return.
+Allows up to a max of 50 list items to return. [max value: 50, default: 20]
 
 
-(B<default: 20>)
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page.
+Used in paging of the list.  This is the start offset of the page. [default: 0]
 
 
-(B<default: 0>)
 
 =item C<sorting>
 
@@ -140,7 +137,6 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 
 
-
 =back
 
 =back
@@ -178,7 +174,7 @@ The properties that can be updated are:
 
 =item C<name>
 
-B<(required)>
+Name of the plan. [min length: 2] (B<required>) 
 
 Authentication is done using the same credentials used when the AccessToken was created.
 
@@ -198,11 +194,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.4
+1.0.5
 
 =head1 LICENSE
 
-Copyright (c) 2013, MasterCard International Incorporated
+Copyright (c) 2013, 2014 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
