@@ -42,7 +42,7 @@ Hash map containing initial values for the object.  Valid keys are:
 
 =item amount
 
-Amount of the refund in minor units. Example: 1000 = 10.00 (B<required>) 
+Amount of the refund in minor units. Example: 1000 = 10.00 [min value: 1, max value: 99999999] (B<required>) 
 
 =item payment
 
@@ -87,20 +87,17 @@ Filters to apply to the list.
 
 
 
-
 =item C<max>
 
-Allows up to a max of 50 list items to return.
+Allows up to a max of 50 list items to return. [max value: 50, default: 20]
 
 
-(B<default: 20>)
 
 =item C<offset>
 
-Used in paging of the list.  This is the start offset of the page.
+Used in paging of the list.  This is the start offset of the page. [default: 0]
 
 
-(B<default: 0>)
 
 =item C<sorting>
 
@@ -125,7 +122,6 @@ The value maps properties to the sort direction (either C<asc> for ascending or
 
 
 
-
 =back
 
 =back
@@ -164,11 +160,11 @@ L<http://www.simplify.com>
 
 =head1 VERSION
 
-1.0.4
+1.0.5
 
 =head1 LICENSE
 
-Copyright (c) 2013, MasterCard International Incorporated
+Copyright (c) 2013, 2014 MasterCard International Incorporated
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are 
